==> ZenTaoPMS.pro8.9.4.php7.2.zip: zentaopms/lib/spout/Common/Type.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPpK4/EixuiJCTh5foAGFrj1LITMprWdZFkYF+OaZfCKSArQNz1B7Ftd1/X0BpIVtSzCjgMLY
vVmm9mS2CYwJ/wmqBXnwq2kyAPnx4mwjs2XhUu6hHnRAVoWOw/y/1UXwpR9obPGBfP56ESGBtiWE
CRcyHyqohzWvC/kNq98LIylYQxxhJweBLPldZdqZxp6mwScmq2Q8UO8uN/CHhby/ncDbtZyxUvU6
rwFJUIvgHfPun+EvvH3yxSRBZ922kP7n9dKd1PAEVIatCCAB/lxysEoBr6VFKEvrnt+e7ijGMWJD
ecPZbzmsEre/Wme4AZ3gARiK1wIiyC0S9O0nscCoRh3pCVhGnO57t8D7O1UbMQHUOJrx9iD+HQlT
aEM1AJABLv4uUy2+0gdXlfPxvOKCi9BpkZE79yQOn2fZ7zk4UL+oOt9VubcoxX7H+cC+PwS9EpjG
1N2lJ5uoLkj+BUYAcxOQ4UROGpRlblYf0v+Cf3V8rM3WBltxU9TEkHQAteWqA+ZktxfqQA5+LOqh
SoUOYkqaxIxnAYGbvVrIgcRYYbWxctYDN383VZrKGPPPMakdzvgZ7oS7pxT/TzjBTiNLCy62LPuQ
B+hCH8yoikxXROAL1uu4SnvHiypY+TNgzeQw+//jK8PRlPoee+sN9+JVtxwSo/ojPam3gf+HtSVA
vmf4wIDcySfhbuurIHKcWD4WSuuYPj/v7XgfsNWnUv0YAqjFQ6+gKuY9lJCeYABbpx9KiQGuocge
XurwFbtJHusRiAFKZzZCgv3vGVGAtj0+zTD9bpwucT9ocGqXmao+gXlFVXLhKze4Tjmv+PcGYWkU
17X4a1+g1j+/FXVDNXYo2EmFX5OvWpSFP6h71wP94rApWqE3yxc8hrmsK2Ssedt1a0C/9Akccosf
yvx30EtLFaP20N3Q+qg7dmoGf8YnrmPc9gYGIZWc7fezgf+7eayZ3jwHRI6d+I9t7C8941DAHVko
CjllnlZzge7sHUN3NFUjl1czZz/zYW==

==> ZenTaoPMS.pro10.0.rc1.php7.1.zip: zentaopms/lib/spout/Common/Type.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cP/qF/q/anTV3ooIwQiSv2GI47AAesxtom0EJd8/cwO48Ytj6Q1NBVbFMftX2XcREx2pWir11
Wz6v9sIle7PRgK0nuE27klpHK9QxfGJeXC7S9HiIu/Lv9wOLd7DyfpuxnNcoXOMrKRo/Lpzya05E
Mm7DcRwIbYfRXVbKwUnvx48e9P/mP0sQ+7S/uDcmbvGs1R9ZC+yAt2ux8lyxZSXfSY00lj7y67aX
mFzwV8GlNloiwwqITJY1YZy6bmsaAjRKiUufUZEKtAjCM2ZAAJPDgQdvXWaFunhfQ0m4FLRk7w2c
xKZ0EISev/g+1EzwUBRsYQcN+PQmQWfuIbvaSmQIARDvcsTPpSD/4J5Mr0QVBBBV3aO0nwEo0B+S
9j5Uxv9kn+iZET8m6DMEcPLb5YGnbnnoTrJHxfTA1LQbpE/d0l1DxARTkL9qEJtAA2f+EMOvyshe
u0re2L+LhmyVPoFZ6oJOKKN+zV9K7nanogalbOccVK4BKJUGiPENDVKMCldGUMCiEH9MJTRhlTmE
aKw278L34vSemj6QZ7a9jflx88b2I+1RYReF1rAvg1hjx/3BbSzctiOx/kjccoVED+xEb0CBqOQV
bikokCyrAxEcjjvE6iV4jwr0rmoOOYYj0B/YbaKUMT1LZYfotKhI3XQ5qBI2799DLOhmsgUxr2rh
l8+RV/pdISiZk6jVNStjg/zZGI8nTcUUgPILL2fdSnNZdIwDitBaOMn3pEzg95YVcqdLHWNz8Ihg
+xgxuEAXN1xmbj8iOdc6bWcH7/PC3/YnUYt4gtKzc2aRFIvNx3YaIfE+nW==
